==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/integration-tests/it-edge/src/main/java/org/apache/servicecomb/it/edge/converter/CustomExceptionConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.it.edge.converter;

import java.util.concurrent.TimeoutException;

import javax.ws.rs.core.Response.Status;

import org.apache.servicecomb.swagger.invocation.Response;
import org.apache.servicecomb.swagger.invocation.SwaggerInvocation;
import org.apache.servicecomb.swagger.invocation.exception.ExceptionToProducerResponseConverter;
import org.apache.servicecomb.swagger.invocation.exception.InvocationException;

public class CustomExceptionConverter implements ExceptionToProducerResponseConverter<TimeoutException> {
  @Override
  public Class<TimeoutException> getExceptionClass() {
    return TimeoutException.class;
  }

  @Override
  public int getOrder() {
    return -12;
  }

  @Override
  public Response convert(SwaggerInvocation swaggerInvocation, TimeoutException e) {
    CustomException customException = new CustomException("change the response", 777);
    InvocationException stt = new InvocationException(Status.EXPECTATION_FAILED, customException);
    return Response.failResp(stt);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.1-src.zip: apache-servicecomb-java-chassis-distribution-2.8.1-src/integration-tests/it-edge/src/main/java/org/apache/servicecomb/it/edge/converter/CustomExceptionConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.it.edge.converter;

import javax.ws.rs.core.Response.Status;

import org.apache.servicecomb.swagger.invocation.Response;
import org.apache.servicecomb.swagger.invocation.SwaggerInvocation;
import org.apache.servicecomb.swagger.invocation.exception.ExceptionToProducerResponseConverter;
import org.apache.servicecomb.swagger.invocation.exception.InvocationException;

public class CustomExceptionConverter implements ExceptionToProducerResponseConverter<InvocationException> {
  @Override
  public Class<InvocationException> getExceptionClass() {
    return InvocationException.class;
  }

  @Override
  public int getOrder() {
    return -12;
  }

  @Override
  public Response convert(SwaggerInvocation swaggerInvocation, InvocationException e) {
    if (e.getStatusCode() == 408) {
      CustomException customException = new CustomException("change the response", 777);
      InvocationException stt = new InvocationException(Status.EXPECTATION_FAILED, customException);
      return Response.failResp(stt);
    } else {
      return Response.failResp(e);
    }
  }
}
